@@ -354,59 +354,60 @@ def dist_stats(H):
      dist_stats : dict
         Dictionary which keeps track of each of the above items (e.g., basic['nrows'] = the number of nodes in H)
     """
-    stats = H.state_dict.get("dist_stats", None)
-    if stats is not None:
-        return H.state_dict["dist_stats"]
-    else:
-        cstats = ["min", "max", "mean", "median", "std"]
-        basic = dict()
+    if H.isstatic:
+        stats = H.state_dict.get("dist_stats", None)
+        if stats is not None:
+            return H.state_dict["dist_stats"]
 
-        # Number of rows (nodes), columns (edges), and aspect ratio
-        basic["nrows"] = len(H.nodes)
-        basic["ncols"] = len(H.edges)
-        basic["aspect ratio"] = basic["nrows"] / basic["ncols"]
+    cstats = ["min", "max", "mean", "median", "std"]
+    basic = dict()
 
-        # Number of cells and density
-        M = H.incidence_matrix(index=False)
-        basic["ncells"] = M.nnz
-        basic["density"] = basic["ncells"] / (basic["nrows"] * basic["ncols"])
+    # Number of rows (nodes), columns (edges), and aspect ratio
+    basic["nrows"] = len(H.nodes)
+    basic["ncols"] = len(H.edges)
+    basic["aspect ratio"] = basic["nrows"] / basic["ncols"]
 
-        # Node degree distribution
-        basic["node degree list"] = sorted(degree_dist(H), reverse=True)
-        basic["node degree centrality stats"] = dict(
-            zip(cstats, centrality_stats(basic["node degree list"]))
-        )
-        basic["node degree hist"] = Counter(basic["node degree list"])
-        basic["max node degree"] = max(basic["node degree list"])
+    # Number of cells and density
+    M = H.incidence_matrix(index=False)
+    basic["ncells"] = M.nnz
+    basic["density"] = basic["ncells"] / (basic["nrows"] * basic["ncols"])
 
-        # Edge size distribution
-        basic["edge size list"] = sorted(H.edge_size_dist(), reverse=True)
-        basic["edge size centrality stats"] = dict(
-            zip(cstats, centrality_stats(basic["edge size list"]))
-        )
-        basic["edge size hist"] = Counter(basic["edge size list"])
-        basic["max edge size"] = max(basic["edge size hist"])
+    # Node degree distribution
+    basic["node degree list"] = sorted(degree_dist(H), reverse=True)
+    basic["node degree centrality stats"] = dict(
+        zip(cstats, centrality_stats(basic["node degree list"]))
+    )
+    basic["node degree hist"] = Counter(basic["node degree list"])
+    basic["max node degree"] = max(basic["node degree list"])
 
-        # Component size distribution (nodes)
-        basic["comp nodes list"] = sorted(s_comp_dist(H, edges=False), reverse=True)
-        basic["comp nodes hist"] = Counter(basic["comp nodes list"])
-        basic["comp nodes centrality stats"] = dict(
-            zip(cstats, centrality_stats(basic["comp nodes list"]))
-        )
+    # Edge size distribution
+    basic["edge size list"] = sorted(H.edge_size_dist(), reverse=True)
+    basic["edge size centrality stats"] = dict(
+        zip(cstats, centrality_stats(basic["edge size list"]))
+    )
+    basic["edge size hist"] = Counter(basic["edge size list"])
+    basic["max edge size"] = max(basic["edge size hist"])
 
-        # Component size distribution (edges)
-        basic["comp edges list"] = sorted(s_comp_dist(H, edges=True), reverse=True)
-        basic["comp edges hist"] = Counter(basic["comp edges list"])
-        basic["comp edges centrality stats"] = dict(
-            zip(cstats, centrality_stats(basic["comp edges list"]))
-        )
+    # Component size distribution (nodes)
+    basic["comp nodes list"] = sorted(s_comp_dist(H, edges=False), reverse=True)
+    basic["comp nodes hist"] = Counter(basic["comp nodes list"])
+    basic["comp nodes centrality stats"] = dict(
+        zip(cstats, centrality_stats(basic["comp nodes list"]))
+    )
 
-        # Number of components
-        basic["num comps"] = len(basic["comp nodes list"])
+    # Component size distribution (edges)
+    basic["comp edges list"] = sorted(s_comp_dist(H, edges=True), reverse=True)
+    basic["comp edges hist"] = Counter(basic["comp edges list"])
+    basic["comp edges centrality stats"] = dict(
+        zip(cstats, centrality_stats(basic["comp edges list"]))
+    )
 
-        # # Diameters
-        # basic['s edge diam list'] = s_edge_diameter_dist(H)
-        # basic['s node diam list'] = s_node_diameter_dist(H)
-        if H.isstatic:
-            H.set_state(dist_stats=basic)
-        return basic
+    # Number of components
+    basic["num comps"] = len(basic["comp nodes list"])
+
+    # # Diameters
+    # basic['s edge diam list'] = s_edge_diameter_dist(H)
+    # basic['s node diam list'] = s_node_diameter_dist(H)
+    if H.isstatic:
+        H.set_state(dist_stats=basic)
+    return basic
